@@ -29,14 +29,15 @@
 #include <kbuttonbox.h>
 #include <kfiledialog.h>
 #include <kseparator.h>
-#include <kapp.h>
+#include <klocale.h>
+#include <kapplication.h>
 
 
 #include <unistd.h>
-#include "portablekde.h"
 #include "execdlg.h"
 #include "dirmanager.h"
 #include <arts/debug.h>
+#include <qpushbutton.h>
 
 #ifndef KDE_USE_FINAL
 static void min_size(QWidget *w) {
