@@ -34,7 +34,7 @@ class NameDlg :public QDialog {
 	Q_OBJECT
 	QLineEdit *edit;
 public:
-	NameDlg(QWidget *parent, const char *oldname, const char *title);
-	const char *name();
+	NameDlg(QWidget *parent, const QString &oldname, const QString &title);
+	QString name();
 };
 #endif
