@@ -17,15 +17,16 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Send comments and bug fixes to antlarr@arrakis.es
+    Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
 #include <qpushbutton.h>
 #include <qlistbox.h>
 #include <qlabel.h> 
+#include <qlayout.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -34,76 +35,72 @@
 #include "midicfgdlg.h"
 #include "version.h"
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
-MidiConfigDialog::MidiConfigDialog(DeviceManager *dm, QWidget *parent,const char *name) : QDialog(parent,name,TRUE)
+MidiConfigDialog::MidiConfigDialog(DeviceManager *dm,
+    QWidget *parent,const char *name) : KDialogBase(parent,name,TRUE,
+      i18n("Configure Midi devices"), KDialogBase::Ok|KDialogBase::Cancel)
 {
-setCaption(i18n("Configure Midi devices"));
-setMinimumSize(360,240);
-setMaximumSize(360,240);
-ok=new QPushButton(i18n("OK"),this);
-ok->setGeometry(140,200,100,30);
-connect(ok,SIGNAL(clicked()),SLOT(accept()) );
-cancel=new QPushButton(i18n("Cancel"),this);
-cancel->setGeometry(250,200,100,30);
-connect(cancel,SIGNAL(clicked()),SLOT(reject()) );
+  setMinimumSize(360,240);
+  QWidget *page = new QWidget( this );
+  setMainWidget(page);
 
-label=new QLabel(i18n("Select the midi device you want to use :"),this);
-label->adjustSize();
-label->move(10,10);
-mididevices=new QListBox(this,"midideviceslist");
-mididevices->setGeometry(10,30,340,60);
-connect(mididevices,SIGNAL(highlighted(int)),SLOT(deviceselected(int)));
-devman=dm;
-char temp[200];
-for (int i=0;i<devman->midiPorts()+devman->synthDevices();i++)
-    {
+  QVBoxLayout *topLayout=new QVBoxLayout(page, 0, spacingHint());
+  QLabel *label=new QLabel(i18n("Select the midi device you want to use :"),page);
+  topLayout->addWidget(label);
+  mididevices=new QListBox(page,"midideviceslist");
+  topLayout->addWidget(mididevices,3);
+  connect(mididevices,SIGNAL(highlighted(int)),SLOT(deviceselected(int)));
+  devman=dm;
+  QString temp;
+  for (int i=0;i<devman->midiPorts()+devman->synthDevices();i++)
+  {
     if (strcmp(devman->type(i),"")!=0)    
-        sprintf(temp,"%s - %s",devman->name(i),devman->type(i));
-       else
-        sprintf(temp,"%s",devman->name(i));
+      temp = QString("%1 - %2").arg(devman->name(i)).arg(devman->type(i));
+    else
+      temp = devman->name(i);
 
     mididevices->insertItem(temp,i);
-    };
-selecteddevice=devman->defaultDevice();
-mididevices->setCurrentItem(selecteddevice);
+  };
+  selecteddevice=devman->defaultDevice();
+  mididevices->setCurrentItem(selecteddevice);
 
-label2=new QLabel(i18n("Use the midi map :"),this);
-label2->adjustSize();
-label2->move(10,100);
+  QLabel *label2=new QLabel(i18n("Use the midi map :"),page);
+  topLayout->addWidget(label2);
 
 
-if (selectedmap!=NULL) delete selectedmap;
-if (strcmp(devman->midiMapFilename(),"")==0)
+  if (selectedmap!=NULL) delete selectedmap;
+  if (strcmp(devman->midiMapFilename(),"")==0)
     selectedmap=NULL;
-   else
-    {
+  else
+  {
     selectedmap=new char[strlen(devman->midiMapFilename())+1];
     strcpy(selectedmap,devman->midiMapFilename());
-    };
+  }
 
-if (selectedmap!=NULL) maplabel=new QLabel(selectedmap,this);
-   else maplabel=new QLabel(i18n("None"),this);
+  if (selectedmap!=NULL) maplabel=new QLabel(selectedmap,page);
+  else maplabel=new QLabel(i18n("None"),page);
 
-maplabel->adjustSize();
-maplabel->move(10,100+label2->height());
+  topLayout->addWidget(maplabel);
 
-mapbrowse=new QPushButton(i18n("Browse..."),this);
-mapbrowse->adjustSize();
-mapbrowse->move(170,140);
-connect(mapbrowse,SIGNAL(clicked()),SLOT(browseMap()) );
+  QHBoxLayout *hbox=new QHBoxLayout(topLayout);
+  hbox->addStretch(1);
+  mapbrowse=new QPushButton(i18n("Browse..."),page);
+  hbox->addWidget(mapbrowse);
+  connect(mapbrowse,SIGNAL(clicked()),SLOT(browseMap()) );
 
-mapnone=new QPushButton(i18n("None"),this);
-mapnone->adjustSize();
-mapnone->move(170+mapbrowse->width()+10,140);
-connect(mapnone,SIGNAL(clicked()),SLOT(noMap()) );
+  mapnone=new QPushButton(i18n("None"),page);
+  hbox->addWidget(mapnone);
+  connect(mapnone,SIGNAL(clicked()),SLOT(noMap()) );
 
-};
+  topLayout->addStretch(1);
+
+}
 
 void MidiConfigDialog::deviceselected(int idx)
 {
-selecteddevice=idx;
-};
+  selecteddevice=idx;
+}
 
 void MidiConfigDialog::browseMap()
 {
@@ -117,7 +114,7 @@ void MidiConfigDialog::browseMap()
 
   if( !url.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+    KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
     return;
   }
 
@@ -127,15 +124,15 @@ void MidiConfigDialog::browseMap()
   selectedmap=new char[filename.length()+1];
   strcpy(selectedmap,filename.ascii());
   maplabel->setText(selectedmap);
-  maplabel->adjustSize();
-};
+}
 
 void MidiConfigDialog::noMap()
 {
-if (selectedmap!=NULL) {delete selectedmap;selectedmap=NULL;}; 
-maplabel->setText(i18n("None"));
-maplabel->adjustSize();
-};
+  if (selectedmap!=NULL) {delete selectedmap;selectedmap=NULL;}; 
+  maplabel->setText(i18n("None"));
+}
 
 int MidiConfigDialog::selecteddevice=0;
 char *MidiConfigDialog::selectedmap=NULL;
+
+#include "midicfgdlg.moc"
