@@ -22,6 +22,7 @@
 #include <iostream.h>
 #include <stdlib.h>
 
+#include <qcursor.h>
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
@@ -225,14 +226,12 @@ void KMixerWidget::saveConfig( KConfig *config, QString grp )
       config->writeEntry( "Split", !chn->dev->isStereoLinked() );
       config->writeEntry( "Show", !chn->dev->isDisabled() );
 
-      QString devgrpkeys;
-      devgrpkeys.sprintf( "%s.Dev%i.keys", grp.ascii(), n );
-
       KGlobalAccel *keys=chn->dev->keys();
       if (keys) {
 	 QString devgrpkeys;
 	 devgrpkeys.sprintf( "%s.Dev%i.keys", grp.ascii(), n );
-	 KAccel::writeKeyMap(keys->keyDict(),devgrpkeys,config);
+	 keys->setConfigGroup(devgrpkeys);
+	 keys->writeSettings(config);
       }
       n++;
    }
@@ -260,9 +259,9 @@ void KMixerWidget::loadConfig( KConfig *config, QString grp )
 	 QString devgrpkeys;
 	 devgrpkeys.sprintf( "%s.Dev%i.keys", grp.ascii(), n );
 
-	 KKeyEntryMap keymap=keys->keyDict();
-	 KAccel::readKeyMap(keymap,devgrpkeys,config);
-	 keys->setKeyDict(keymap);
+	 keys->setConfigGroup(devgrpkeys);
+	 keys->readSettings(config);
+	 keys->updateConnections();
       }
 
       n++;
