@@ -178,6 +178,7 @@ Mixer::Mixer( int device, int card )
   m_balance = 0;
   m_mixDevices.setAutoDelete( true );
   m_profiles.setAutoDelete( true );
+  m_mixerNum = 0;
 };
 
 int Mixer::setupMixer( MixSet mset )
@@ -209,7 +210,7 @@ void Mixer::volumeLoad( KConfig *config )
    m_mixDevices.read( config, grp );
 
    // set new settings
-   QListIterator<MixDevice> it( m_mixDevices );
+   QPtrListIterator<MixDevice> it( m_mixDevices );
    for(MixDevice *md=it.toFirst(); md!=0; md=++it )
    {
       setRecsrc( md->num(), md->isRecsrc() );
@@ -256,7 +257,7 @@ unsigned int Mixer::size() const
 MixDevice* Mixer::operator[](int num)
 {
   MixDevice* md =  m_mixDevices.at( num );
-  ASSERT( md );
+  Q_ASSERT( md );
   return md;
 }
 
@@ -307,6 +308,17 @@ QString Mixer::mixerName()
   return m_mixerName;
 }
 
+
+void Mixer::setMixerNum( int num )
+{
+    m_mixerNum = num;
+}
+
+int Mixer::mixerNum()
+{
+    return m_mixerNum;
+}
+
 void Mixer::errormsg(int mixer_error)
 {
   QString l_s_errText;
@@ -320,7 +332,7 @@ QString Mixer::errorText(int mixer_error)
   switch (mixer_error)
     {
     case ERR_PERM:
-      l_s_errmsg = i18n("kmix:You have no permission to access the mixer device.\n" \
+      l_s_errmsg = i18n("kmix:You do not have permission to access the mixer device.\n" \
 			"Please check your operating systems manual to allow the access.");
       break;
     case ERR_WRITE:
@@ -340,15 +352,15 @@ QString Mixer::errorText(int mixer_error)
       break;
     case ERR_OPEN:
       l_s_errmsg = i18n("kmix: Mixer cannot be found.\n" \
-			"Please check that the soundcard is installed and the\n" \
-			"soundcard driver is loaded\n");
+			"Please check that the soundcard is installed and that\n" \
+			"the soundcard driver is loaded.\n");
       break;
     case ERR_INCOMPATIBLESET:
       l_s_errmsg = i18n("kmix: Initial set is incompatible.\n" \
 			"Using a default set.\n");
       break;
     default:
-      l_s_errmsg = i18n("kmix: Unknown error. Please report, how you produced this error.");
+      l_s_errmsg = i18n("kmix: Unknown error. Please report how you produced this error.");
       break;
     }
   return l_s_errmsg;
