@@ -1,7 +1,7 @@
 /*
  * Kscd - A simple cd player for the KDE Project
  *
- * $Id: kscd.cpp,v 1.152 2002/03/20 05:25:32 aseigo Exp $
+ * $Id: kscd.cpp,v 1.152.2.1 2002/07/19 08:47:15 porten Exp $
  *
  * Copyright (c) 1997 Bernd Johannes wuebben@math.cornell.edu
  *
@@ -378,10 +378,10 @@ KSCD::initFont()
           fits = true;
       }
   }
-  
+
   smallfont = QFont(KGlobalSettings::generalFont().family(), theSmallPtSize, QFont::Bold);
-  verysmallfont = QFont(KGlobalSettings::generalFont().family(), 
-                        (theSmallPtSize > 4) ? theSmallPtSize - 2 : 2, 
+  verysmallfont = QFont(KGlobalSettings::generalFont().family(),
+                        (theSmallPtSize > 4) ? theSmallPtSize - 2 : 2,
                         QFont::Bold);
 } // initFont()
 
@@ -641,9 +641,9 @@ KSCD::showPopup()
 } // showPopup
 
 
-void 
+void
 KSCD::setRandomOnce(bool shuffle)
-{ 
+{
     randomonce = shuffle;
     QToolTip::remove(shufflebutton);
     if (!randomonce)
@@ -694,8 +694,8 @@ KSCD::setToolTips(bool on)
         {
             QToolTip::add(shufflebutton,         i18n("Shuffle Play"));
         }
-    } 
-    else 
+    }
+    else
     {
         QToolTip::remove(playPB);
         QToolTip::remove(stopPB);
@@ -1114,7 +1114,7 @@ KSCD::trackSelected( int trk )
     {
         return;
     }
-    
+
     randomplay = false;
     tracklabel->setText( formatTrack( trk + 1, cd->ntracks ) );
 
@@ -1162,18 +1162,18 @@ KSCD::aboutClicked()
 void
 KSCD::configDone()
 {
-    delete configDialog;
+    // dialog deletes itself
     configDialog = 0L;
 }
 
-void 
+void
 KSCD::getCDDBOptions(CDDBSetup* config)
 {
     if (!config)
     {
-        return;    
+        return;
     }
-    
+
     config->insertData(cddbserverlist,
                        cddbsubmitlist,
                        cddbbasedir,
@@ -1188,12 +1188,12 @@ KSCD::getCDDBOptions(CDDBSetup* config)
 } // getCDDBOptions(CDDBSetup* config)
 
 
-void 
+void
 KSCD::setCDDBOptions(CDDBSetup* config)
 {
     if (!config)
     {
-        return;    
+        return;
     }
 
     bool cddb_proxy_enabled;
@@ -1218,7 +1218,7 @@ KSCD::setCDDBOptions(CDDBSetup* config)
 } // setCDDBOptions
 
 
-void 
+void
 KSCD::getMagicOptions(mgconfigstruct& config)
 {
     config.width = magic_width;
@@ -1228,8 +1228,8 @@ KSCD::getMagicOptions(mgconfigstruct& config)
 } // getMagicOptions(mgconfigstruct& config)
 
 
-void 
-KSCD::setMagicOptions(mgconfigstruct& config)
+void
+KSCD::setMagicOptions(const mgconfigstruct& config)
 {
     magic_width = config.width;
     magic_height = config.height;
@@ -1238,12 +1238,12 @@ KSCD::setMagicOptions(mgconfigstruct& config)
 } // setMagicOptions(mgconfigstruct& config)
 
 
-void 
-KSCD::setDevicePath(QString path) 
+void
+KSCD::setDevicePath(QString path)
 {
     if (cd_device_str == path)
     {
-        return;    
+        return;
     }
 
     cd_device_str = path;
@@ -1260,9 +1260,9 @@ KSCD::setDevicePath(QString path)
     cddrive_is_ok = true;
 } // setDevicePath(QString)
 
-void 
-KSCD::setDocking(bool dock) 
-{ 
+void
+KSCD::setDocking(bool dock)
+{
     docking = dock;
     if(docking)
     {
@@ -1286,7 +1286,7 @@ KSCD::incVolume()
     volSB->addStep();
 } // incVolume
 
-void 
+void
 KSCD::decVolume()
 {
     volSB->subtractStep();
@@ -1297,7 +1297,7 @@ KSCD::volChanged( int vol )
 {
     if(volstartup || !cddrive_is_ok)
         return;
-    
+
     QString str;
     str = QString::fromUtf8( QCString().sprintf( i18n("Vol: %02d%%").utf8(),vol) );
     volumelabel->setText(str);
@@ -1309,7 +1309,7 @@ KSCD::volChanged( int vol )
 int
 KSCD::randomtrack()
 {
-    if(random_list == 0) 
+    if(random_list == 0)
     {
         return -1;
     }
@@ -1378,7 +1378,7 @@ KSCD::cdMode()
 
   sss = wm_cd_status();
 
-  if( sss == WM_CDS_JUST_INSERTED  || sss == WM_CDS_NO_DISC) 
+  if( sss == WM_CDS_JUST_INSERTED  || sss == WM_CDS_NO_DISC)
   {
       have_new_cd = true;
   }
@@ -3066,7 +3066,7 @@ KSCD::keyPressEvent(QKeyEvent* e)
 {
     bool isNum;
     int value = e->text().toInt(&isNum);
-    
+
     if (isNum)
     {
         value = (jumpToTrack * 10) + value;
@@ -3095,19 +3095,19 @@ KSCD::jumpTracks()
     jumpToTrack = 0;
 } // jumpTracks
 
-int KSCD::currentTrack() 
-{ 
-    return cur_track; 
+int KSCD::currentTrack()
+{
+    return cur_track;
 }
 
-QString KSCD::currentTrackTitle() 
-{ 
+QString KSCD::currentTrackTitle()
+{
     return (cur_track > -1) ? tracktitlelist[cur_track] : QString::null;
 }
 
-QStringList KSCD::trackList() 
-{ 
-    return tracktitlelist; 
+QStringList KSCD::trackList()
+{
+    return tracktitlelist;
 }
 
 /**
