@@ -19,18 +19,15 @@ FileInputStream::FileInputStream() {
   file=NULL;
   lopen=false;
   fileLen=0;
-  abs_thread_mutex_init(&fileMut);
 }
 
 
 FileInputStream::~FileInputStream() {
   close();
-  abs_thread_mutex_destroy(&fileMut);
 }
 
 
 int FileInputStream::open(const char* dest) {
-  char* filename=NULL;
 
   close();
   if (dest == NULL) {
@@ -39,51 +36,33 @@ int FileInputStream::open(const char* dest) {
   setUrl(dest);
   if (strlen(dest) == 1) {
     if (strncmp(dest,"-",1)==0) {
-      lockFile();
       file=::fdopen(0,"rb");
-      unlockFile();
     }
   }
   // load out of current dir if no full path is given
-  if (strlen(dest) > 1) {
-    if ( (dest[0] != '/') &&
-         (dest[0] != '.') ) {
-      filename=new char[strlen(dest)+3];  // prefix with ./ plus zero at end
-      filename[0]='.';
-      filename[1]='/';
-      memcpy(filename+2,dest,strlen(dest)+1); // copy with zero
-    } else {
-      filename=strdup(dest);
-    }
-  }
-  lockFile();
   if (file == NULL) {
-    file=fopen(filename,"rb");
+    file=fopen(dest,"rb");
   }
   fileLen=0;
   if (file == NULL) {
-    cout << dest<<endl;
-    perror("cannot open file");
+    cout <<"cannot open file:"<< dest<<endl;
+
   } else {
     lopen=true;
     struct stat fileStat;
-    stat(filename,&fileStat);
+    stat(dest,&fileStat);
     fileLen=(long)fileStat.st_size;
   }
   int back=(file!=NULL);
-  unlockFile();
-  delete filename;
   return back;
 }
 
 
 void FileInputStream::close() {
   if (isOpen()) {
-    lockFile();
     ::fclose(file);
     file=NULL;
     lopen=false;
-    unlockFile();
   }
 }
 
@@ -98,11 +77,9 @@ int FileInputStream::eof() {
     return true;
   }
   int back=true;
-  lockFile();
   if (file != NULL) {
     back=feof(file);
   }
-  unlockFile();
 
   return back;
 }
@@ -115,19 +92,13 @@ int FileInputStream::read(char* ptr,int size) {
       cout << "size is <= 0!"<<endl;
       return 0;
     }
-    lockFile();
     if (file != NULL) {
       bytesRead=fread(ptr,1,size,file);
     }
-    unlockFile();
   } else {
     cerr << "read on not open file want:"<<size<<endl;
     return 0;
   }
-  if (bytesRead == 0){
-    perror("zero bytes fread");
-    bytesRead=0;
-  }
   return bytesRead;
 }
 
@@ -137,15 +108,13 @@ int FileInputStream::seek(long posInBytes) {
   if (isOpen()==false) {
     return false;
   }
-  lockFile();
   long pos=-1;
   if (file != NULL) {
     pos=fseek(file,posInBytes,SEEK_SET);
   }
-  unlockFile();
 
   if (pos < 0) {
-    perror("seek in setBytePos");
+    cout <<"seek error in FileInputStream::seek"<<endl;
     back=false;
   }
   return back;
@@ -160,11 +129,9 @@ long FileInputStream::getByteLength() {
 long FileInputStream::getBytePosition() {
   int back=0;
   if (isOpen()) {
-    lockFile();
     if (file != NULL) {
       back=ftell(file);
     }
-    unlockFile();
   }
   return back;
 }
@@ -176,13 +143,3 @@ void FileInputStream::print() {
 }
 
 
-void FileInputStream::lockFile() {
-  abs_thread_mutex_lock(&fileMut);
-}
-
-
-
-void FileInputStream::unlockFile() {
-  abs_thread_mutex_unlock(&fileMut);
-}
-
