@@ -130,6 +130,10 @@ int OutputStream::openWindow(int , int ,const char* ) {
   return true;
 }
 
+int OutputStream::x11WindowId() {
+ cout << "direct virtual call OutputStream::x11WindowId()" << endl;
+ return -1;
+}
 
 void OutputStream::closeWindow() {
   cerr << "direct virtual call OutputStream::closeWindow"<<endl;
@@ -171,7 +175,7 @@ void OutputStream::setOutputInit(int lInit) {
 
 
 void OutputStream::writeInfo(PluginInfo* ) {
-  cerr << "direct virtual call OutputStream::writeInfo"<<endl;
+
 }
 
 
